@@ -18,6 +18,8 @@ with(persistent, {
         expect_equal_to_reference(base_cvis, file_name(base_cvis))
         expect_equal_to_reference(cvis_tadp, file_name(cvis_tadp))
         expect_equal_to_reference(cvis_hc, file_name(cvis_hc))
+        expect_equal_to_reference(cvis_tadp, file_name(cvis_tadp_cent))
+        expect_equal_to_reference(cvis_hc, file_name(cvis_hc_cent))
     })
 })
 
